==> mysql-cluster-gpl-7.1.23.zip: mysql-cluster-gpl-7.1.23/storage/ndb/clusterj/clusterj-api/src/main/java/com/mysql/clusterj/annotation/PartitionKey.java <==
/*
   Copyright (c) 2010 Sun Microsystems, Inc.
   Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation on a class or member to define the partition key.
 * If annotating a class or interface, either a single
 * column or multiple columns can be specified.
 * If annotating a member, neither column nor columns should be specified.
 */
@Target({ElementType.TYPE, ElementType.FIELD, ElementType.METHOD}) 
@Retention(RetentionPolicy.RUNTIME)
public @interface PartitionKey
{
    /**
     * Name of the column to use for the partition key
     * @return the name of the column to use for the partition key
     */
    String column() default "";

    /**
     * The column(s) for the partition key
     * @return the column(s) for the partition key
     */
    Column[] columns() default {};
}

==> mysql-cluster-gpl-8.0.28.zip: mysql-cluster-gpl-8.0.28/storage/ndb/clusterj/clusterj-api/src/main/java/com/mysql/clusterj/annotation/PartitionKey.java <==
/*
   Copyright (c) 2010, 2021, Oracle and/or its affiliates.
   Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotation on a class or member to define the partition key.
 * If annotating a class or interface, either a single
 * column or multiple columns can be specified.
 * If annotating a member, neither column nor columns should be specified.
 */
@Target({ElementType.TYPE, ElementType.FIELD, ElementType.METHOD}) 
@Retention(RetentionPolicy.RUNTIME)
public @interface PartitionKey
{
    /**
     * Name of the column to use for the partition key
     * @return the name of the column to use for the partition key
     */
    String column() default "";

    /**
     * The column(s) for the partition key
     * @return the column(s) for the partition key
     */
    Column[] columns() default {};
}
